@@ -868,16 +868,9 @@ import (
 }
 
 func TestErrClassFileGopx(t *testing.T) {
-	codeErrorTestEx(t, "main", "Rect.gopx",
-		`./Rect.gopx:3:2: cannot assign value to field in class file`, `
-var (
-	i int = 1
-)
-println "hello"
-`)
-	codeErrorTestEx(t, "main", "Rect.gopx",
-		`./Rect.gopx:5:2: A redeclared
-	./Rect.gopx:3:2 other declaration of A`, `
+	codeErrorTestEx(t, "main", "Rect.gox",
+		`./Rect.gox:5:2: A redeclared
+	./Rect.gox:3:2 other declaration of A`, `
 var (
 	A
 	i int
@@ -902,3 +895,38 @@ func test() {
 }
 `)
 }
+
+func TestErrInt128(t *testing.T) {
+	codeErrorTest(t, `./bar.gop:2:16: cannot use 1<<127 (type untyped int) as type github.com/goplus/gop/builtin/ng.Int128 in assignment`, `
+var a int128 = 1<<127
+`)
+	codeErrorTest(t, `./bar.gop:2:13: cannot convert 1<<127 (untyped int constant 170141183460469231731687303715884105728) to type Int128`, `
+a := int128(1<<127)
+`)
+	codeErrorTest(t, `./bar.gop:2:13: cannot convert -1<<127-1 (untyped int constant -170141183460469231731687303715884105729) to type Int128`, `
+a := int128(-1<<127-1)
+`)
+	codeErrorTest(t, `./bar.gop:3:13: cannot convert b (untyped int constant -170141183460469231731687303715884105729) to type Int128`, `
+const b = -1<<127-1
+a := int128(b)
+`)
+}
+
+func TestErrUint128(t *testing.T) {
+	codeErrorTest(t, `./bar.gop:2:17: cannot use 1<<128 (type untyped int) as type github.com/goplus/gop/builtin/ng.Uint128 in assignment`, `
+var a uint128 = 1<<128
+`)
+	codeErrorTest(t, `./bar.gop:2:14: cannot convert 1<<128 (untyped int constant 340282366920938463463374607431768211456) to type Uint128`, `
+a := uint128(1<<128)
+`)
+	codeErrorTest(t, `./bar.gop:2:17: cannot use -1 (type untyped int) as type github.com/goplus/gop/builtin/ng.Uint128 in assignment`, `
+var a uint128 = -1
+`)
+	codeErrorTest(t, `./bar.gop:2:14: cannot convert -1 (untyped int constant -1) to type Uint128`, `
+a := uint128(-1)
+`)
+	codeErrorTest(t, `./bar.gop:3:14: cannot convert b (untyped int constant -1) to type Uint128`, `
+const b = -1
+a := uint128(b)
+`)
+}
