@@ -17,6 +17,7 @@
 package parsertest
 
 import (
+	"io/fs"
 	"os"
 	"path"
 	"syscall"
@@ -66,9 +67,9 @@ func NewMemFS(dirs map[string][]string, files map[string]string) *MemFS {
 
 // ReadDir reads the directory named by dirname and returns
 // a list of directory entries sorted by filename.
-func (p *MemFS) ReadDir(dirname string) ([]os.FileInfo, error) {
+func (p *MemFS) ReadDir(dirname string) ([]fs.FileInfo, error) {
 	if items, ok := p.dirs[dirname]; ok {
-		fis := make([]os.FileInfo, len(items))
+		fis := make([]fs.FileInfo, len(items))
 		for i, item := range items {
 			fis[i] = &memFileInfo{name: item}
 		}
@@ -108,4 +109,14 @@ func NewSingleFileFS(dir string, fname string, data string) *MemFS {
 	})
 }
 
+// NewTwoFilesFS creates a file system that contains two files.
+func NewTwoFilesFS(dir string, fname1, data1, fname2, data2 string) *MemFS {
+	return NewMemFS(map[string][]string{
+		dir: {fname1, fname2},
+	}, map[string]string{
+		path.Join(dir, fname1): data1,
+		path.Join(dir, fname2): data2,
+	})
+}
+
 // -----------------------------------------------------------------------------
